Usage
entrez_fetch(db, id = NULL, web_history = NULL, rettype, retmode = "",
parsed = FALSE, config = NULL, ...)
Arguments
db
character, name of the database to use
id
vector (numeric or character), unique ID(s) for records in database db
web_history,
a web_history object
rettype
character, format in which to get data (eg, fasta, xml...)
retmode
character, mode in which to receive data, defaults to 'text'
parsed
boolean should entrez_fetch attempt to parse the resulting
file. Only works with xml records (including those with rettypes other than
"xml") at present
config
vector, httr configuration options passed to httr::GET
...
character, additional terms to add to the request, see NCBI
documentation linked to in references for a complete list