Learn R Programming

rentrez (version 1.0.1)

entrez_global_query: Find the number of records that match a given term across all NCBI Entrez databases

Description

Find the number of records that match a given term across all NCBI Entrez databases

Usage

entrez_global_query(term, config = NULL, ...)

Arguments

term
the search term to use
config
vector configuration options passed to httr::GET
...
additional arguments to add to the query

Value

  • a named vector with counts for each a database

See Also

config for available configs

Examples

Run this code
NCBI_data_on_best_butterflies_ever <- entrez_global_query(term="Heliconius")

Run the code above in your browser using DataLab