Learn R Programming

rentrez (version 0.3.1)

entrez_global_query: See how many hits there are for a given term across all NCBI Entrez databses

Description

See how many hits there are for a given term across all NCBI Entrez databses

Usage

entrez_global_query(term, config = NULL, ...)

Arguments

term
the search term to use
config
vector configuration options passed to httr::GET
...
additional arguments to add to the query

Value

  • a named vector with counts for each a datbase

See Also

config for avaliable configs

Examples

Run this code
NCBI_data_on_best_butterflies_ever <- entrez_global_query(term="Heliconius")

Run the code above in your browser using DataLab