Learn R Programming

rentrez (version 0.3.1)

entrez_link: Get links to datasets related to a unique ID from an NCBI database

Description

Contstructs a query with the given arguments and downloands the XML document created by that query. Unique IDs from linked-databases

Usage

entrez_link(db, dbfrom, config = NULL, ...)

Arguments

db
character Name of the database to search for links (or use "all" to earch all NCBI databases
dbfrom
character Name of database from which the Id(s) orginate
...
character Additional terms to add to the request
config
vector configuration options passed to httr::GET

Value

  • An elink object containing vectors of unique IDs the vectors names take the form [db_from]_[db_to]

    file XMLInternalDocument xml file resulting from search, parsed with xmlTreeParse

See Also

config for avaliable configs

Examples

Run this code
pubmed_search <- entrez_search(db = "pubmed", term = "10.1016/j.ympev.2010.07.013[doi]")
 linked_data <- entrez_link(dbfrom = "pubmed", id = pubmed_search$ids, db = "all")
nucleotide_IDs <- linked_data$pubmed_nuccore

Run the code above in your browser using DataLab