Learn R Programming

rentrez (version 1.0.1)

entrez_post: Post IDs to Eutils for later use

Description

Post IDs to Eutils for later use

Usage

entrez_post(db, id = NULL, web_history = NULL, config = NULL, ...)

Arguments

db
character Name of the database from which the IDs were taken
id
vector with unique ID(s) for records in database db.
web_history
A web_history object. Can be used to add to additional identifiers to an existing web environment on the NCBI
config
vector of configuration options passed to httr::GET
...
character Additional terms to add to the request, see NCBI documentation linked to in references for a complete list

References

http://www.ncbi.nlm.nih.gov/books/NBK25499/#_chapter4_EPost_

See Also

config for available httr configurations

Examples

Run this code
so_many_snails <- entrez_search(db="nuccore",
                      "Gastropoda[Organism] AND COI[Gene]", retmax=200)
upload <- entrez_post(db="nuccore", id=so_many_snails$ids)
first <- entrez_fetch(db="nuccore", rettype="fasta", web_history=upload,
                      retmax=10)
second <- entrez_fetch(db="nuccore", file_format="fasta", web_history=upload,
                       retstart=10, retmax=10)

Run the code above in your browser using DataLab