Learn R Programming

rentrez (version 0.3.1)

entrez_post: Post IDs to Eutils for later use

Description

Post IDs to Eutils for later use

Usage

entrez_post(db, id, config = NULL, ...)

Arguments

db
character Name of the database from which the IDs were taken
id
integer ID(s) for which data is being collected
...
character Additional terms to add to the request
config
vector configuration options passed to httr::GET

Value

  • QueryKey integer identifier for specific query in webhistory

    WebEnv character identifier for session key to use with history

See Also

config for avaliable configs

Examples

Run this code
so_many_snails <- entrez_search(db="nuccore",
                      "Gastropoda[Organism] AND COI[Gene]", retmax=200)
upload <- entrez_post(db="nuccore", id=so_many_snails$ids)
cookie <- upload$WebEnv
first <- entrez_fetch(db="nuccore", file_format="fasta", WebEnv=cookie,
                      query_key=upload$QueryKey, retend=10)
second <- entrez_fetch(db="nuccore", file_format="fasta", WebEnv=cookie,
                       query_key=upload$QueryKey, retstart=10)

Run the code above in your browser using DataLab