Note: this function assumes all records are of the type "PubmedArticle" and will return an empty record for any other type (including books).
Arguments
- record
Either and XMLInternalDocument or character the record to be parsed ( expected to come from
entrez_fetch)
Examples
# \donttest{
hox_paper <- entrez_search(db="pubmed", term="10.1038/nature08789[doi]")
#> Error: HTTP failure: 500
#> {"error":"error forwarding request /entrez/eutils/esearch.fcgi?db=pubmed&term=10.1038%2Fnature08789%5Bdoi%5D&retmode=xml&usehistory=n&email=david.winter%40gmail.com&tool=rentrez","api-key":"135.232.200.197","type":"ip",
#> "status":"ok"}
hox_rel <- entrez_link(db="pubmed", dbfrom="pubmed", id=hox_paper$ids)
#> Error: object 'hox_paper' not found
recs <- entrez_fetch(db="pubmed",
id=hox_rel$links$pubmed_pubmed[1:3],
rettype="xml")
#> Error: object 'hox_rel' not found
parse_pubmed_xml(recs)
#> Error: object 'recs' not found
# }